Adaptable case management for youth and family services
Description: With its native cloud architecture, open API, and flexible database platform, ClientTrack is the embodiment of the next-generation system design.

# Youth and Family Services

In August 2015 the Administration for Children and Families proposed a child welfare system update from older SACWIS systems to newer, more modern CCWIS systems. CCWIS systems are distinguished from the legacy SACWIS systems by being smaller, more modular, and designed for interoperability. Unwieldy monolithic systems would give way to a nimble combination of best-in-breed systems working together to further the goals of promoting child welfare.

ClientTrack is the case management system of choice for more than 1,200 government and private agencies. With its native cloud architecture, open API, and flexible database platform, ClientTrack is the embodiment of the next-generation system design envisioned for modern CCWIS systems.

### Easy to Use

Caseworkers love ClientTrack’s ease of use, customizable assessments, and configurable workflows. The system adapts to the needs of your organization rather than forcing you to adapt your workflow to system constraints. Caseworkers are more effective and more productive, which leads to better results and improved outcomes for children and families.

System administrators love ClientTrack’s data integrity, workflow designer, user administration, and superior security. The system grows and adapts as program needs change. With its robust suite of administrative tools, ClientTrack enables in-house staff to make many system enhancements without the need for add-on contracts and additional expense.

- Child and family-centric case management — The case management system puts the child and family at the center of all activity with clearly defined child, sibling, parent, and guardian relationships
- Pre-defined case management tools and workflows — Choose from a library of the most commonly used standardized assessment tools or create your own customized assessments
- Easy-to-navigate screens and workflows that simplify data collection and case management for child welfare
- Individual goals, outcomes, and progress reporting – ClientTrack gives you the flexibility to customize a unique case plan for each child or to assign standardized plans as needs require
- Medication tracking module – Record and track pertinent prescription and dosage information
- Scheduling and calendaring – Schedule appointments, recurring visits, and manage caseworker schedules from an easy-to-use calendar
- Data Explorer and reporting –Data Explorer is a drag-and-drop query-builder that gives you instantaneous answers to pressing questions. ClientTrack’s reporting module provides formatted reports and graphs that give deep insight into your practice performance
- Medical billing and revenue cycle management – patient eligibility checking, CPT and ICD-10 code lookup, medical billing claims submission, 835 claims remit
- Online portal – Secure online portal simplifies data collection and reporting from outside constituencies
- HIPAA and 42 CFR Part 2 Compliance – Built-in security controls with multiple levels of access protect patient data even among caseworkers within the same department
- Interoperability – ClientTrack has an open API for data exchange and is compliant with HL7 version 2.x or above

## Contact Us

First Name * | Last Name *
Email Address * | Phone Number *
Organization
Country
State

### Case Management Suite

Our comprehensive Case Management Suite is built for the unique needs of Health and Human Service organizations.

### Mobile Integration

ClientTrack runs natively as a fully functioning software in all mobile browsers.

### Data Explorer

Data Explorer is a powerful ad-hoc reporting and data analysis tool that enables you to answer any data question, review program activities, and measure outcomes.

### Professional Services

ClientTrack provides comprehensive professional services to ensure our clients receive a world-class implementation.